@@ -1,4 +1,4 @@
-/* $Id: httpd.c,v 1.3 2004/12/05 07:26:12 ichiro Exp $ */
+/* $Id: httpd.c,v 1.6 2005/12/09 16:06:02 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -34,6 +34,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <errno.h>
@@ -77,23 +78,26 @@ httpd(gpointer param)
 
 void httpd_proc(struct tparam *th2, int socket)
 {
+	time_t timer;
+	struct tm *date;
+	
 	char buf[SBUFLEN];
 	char meth_name[64];
 	char channel[C_NAME], channel2[C_NAME];
-	char uri_addr[IRC_MAX];
+	char uri_addr[64];
 	char base64[HTTPBUF];
 	char message[HTTPBUF];
 	char post_message[HTTPBUF + 256]; /* include url_encode mergin */
 	char post_message2[HTTPBUF + 256];
 	char web_user[64], web_pass[64];
-	char *s;
+	char cookie_user[64], cookie_pass[64], date_str[40];
+	char *s, *q;
 	char cmd_cname[C_NAME], cmd_cmd[20], cmd_topic[IRC_MAX];
 	char cmd_buf[IRC_MAX];
-	char *q;
 
 	int n = 0;
 	int r_fd = 0;
-	float http_ver = 0;
+	char http_ver[4];
 
 	int number = 0;
 	int update = 0;
@@ -122,33 +126,82 @@ void httpd_proc(struct tparam *th2, int socket)
 
 	if (read(socket, buf, SBUFLEN) <= 0 ) {
 		printf("error: reading a request.\n");
-	} else if ((sscanf(buf, "%s %s HTTP/%f",
-			meth_name, uri_addr, &http_ver)) < 3) {
+		return;
+	}
+
+	if ((sscanf(buf, "%s %s HTTP/%s\n",
+			meth_name, uri_addr, http_ver)) < 3) {
 		printf("error: catch strings of request.\n");
 	}
 #ifdef DEBUG
-	printf("%s\n", buf);
+	printf("HTTP(DEBUG):meth_name= %s\n", meth_name);
+	printf("HTTP(DEBUG):uri_addr= %s\n", uri_addr);
+	printf("HTTP(DEBUG):http_ver= %s\n", http_ver);
+	printf("---------------------------\n");
+	printf("BUF(DEBUG):%s\n", buf);
+
 #endif
-	/* Authentication */
+	/* Cookie Authentication */
+	if ((p = strstr(buf, "Cookie:")) != NULL) {
+		strcpy(base64, p + 8);
+#ifdef DEBUG
+	printf("DEBUG: Cookie get.\n");
+#endif
+
+		if (sscanf(base64, "user=%[^;]; pass=%s\n",
+		    cookie_user, cookie_pass) == 2);
+		else if (sscanf(base64, "pass=%[^;]; user=%s\n",
+			 cookie_pass, cookie_user) == 2);
+		else
+			printf("DEBUG:error\n");
+	}
+	/* Password Authentication */
 	if ((p = strstr(buf, "Authorization: Basic")) != NULL) {
+#ifdef DEBUG
+	printf("DEBUG: Passwd get.\n");
+#endif
 		strcpy(base64, p + 21);
 		sscanf(base64_decode(base64),
-		       "%[^:]:%[^\n]", web_user, web_pass);
+		       "%[^:]:%s\n", web_user, web_pass);
 	}
-	if ((strcmp(web_user, th2->auth_user) == 0) &&
-	    (strcmp(web_pass, th2->auth_pass) == 0)) {
-		/* check and clear auth info */
-		memset(web_user, 0, sizeof(web_user));
-		memset(web_pass, 0, sizeof(web_pass));
+
+	if ((strcmp(cookie_user, th2->auth_user) == 0) &&
+	    (strcmp(cookie_pass, th2->auth_pass) == 0)) {
+		/* send header HTTP/1.1 200 OK */
+		send_msg(socket, http_header0);
+#ifdef DEBUG
+	printf("DEBUG: Cookie Authentication done.\n");
+#endif
+	} else if ((strcmp(web_user, th2->auth_user) == 0) &&
+		   (strcmp(web_pass, th2->auth_pass) == 0)) {
+		/* send header HTTP/1.1 200 OK */
+		send_msg(socket, http_header0);
+#ifdef DEBUG
+	printf("DEBUG: Passwd Authentication done.\n");
+#endif
+		/* send cookie info */
+		timer = time(NULL) + th2->cookie_expire * 24 * 60 * 60;
+		date = gmtime(&timer);
+		strftime(date_str, 255, "%a, %d-%b-%Y %H:%M:%S GMT;\n", date);
+		/* user */
+		sprintf(message, "Set-Cookie: user=%s; expires=", web_user);
+		strcat(message, date_str);
+		send_msg(socket, message);
+		/* pass */
+		sprintf(message, "Set-Cookie: pass=%s; expires=",web_pass);
+		strcat(message, date_str);
+                send_msg(socket, message);
 	} else {
 		/* cannot auth */
 		send_msg(socket, http_auth_401_header);
 		return;
 	}
 
-#ifdef DEBUG
-	printf("HTTP: %s %s\n", meth_name, uri_addr);
-#endif
+	/* check and clear auth info */
+	memset(web_user, 0, sizeof(web_user));
+	memset(web_pass, 0, sizeof(web_pass));
+	memset(cookie_user, 0, sizeof(cookie_user));
+	memset(cookie_pass, 0, sizeof(cookie_pass));
 
 	/* POST session */
 	if ((strcmp(meth_name, "POST")) == 0) {
@@ -233,6 +286,13 @@ void httpd_proc(struct tparam *th2, int socket)
 				sprintf(post_message, ":%s TOPIC %s :%s\r\n",
 					th2->real_nickname,
 					channel2, cmd_topic);
+			} else if (strcmp(cmd_cmd, "list") == 0) {
+				if (strlen(cmd_cname) > 0) {
+				    url_decode_rawdata(channel, cmd_cname);
+				    channel_decode(channel2, channel);
+				    sprintf(post_message, "NAMES %s\r\n",
+					    channel2); 
+				}
 			} else {
 				goto command_start;
 			}
@@ -255,7 +315,7 @@ void httpd_proc(struct tparam *th2, int socket)
 		if ((r_fd = open(uri_addr, O_RDONLY,
 				 0666)) == -1) {
 			printf("favicon.ico file not found\n");
-		} else if (http_ver == 1.0) {
+		} else if (strcmp(http_ver,"1.0") == 0) {
 			send_msg(socket, ico_header10);
 			while((n = read(r_fd, buf, HTTPBUF)) > 0) {
 			   if (write(socket, buf, n) != n) {
@@ -263,7 +323,10 @@ void httpd_proc(struct tparam *th2, int socket)
 				break;
 			   }
 			} /* while */
-		} /* else if (http_ver == 1.1) { */
+		} else if (strcmp(http_ver,"1.1") == 0) {
+			printf("ver 1.1\n");
+
+		}
 
 		close(r_fd);
 		send_msg(socket, http_footer);
@@ -308,6 +371,11 @@ index_start:
 			th2->topic[number]);
 		send_msg(socket, message);
 
+		/* print NAMES */
+		sprintf(message, "member:%s<br>",
+			th2->member_names[number]);
+		send_msg(socket, message);
+
 		/* print FORM */
 		sprintf(message,
 			"<form action=\"/channel%d\" method=\"post\">",
@@ -411,6 +479,8 @@ void print_command_page(int socket)
 		"<br><input type=radio name=\"cmd\" value=\"join\">JOIN");
 	send_msg(socket,
 		"<br><input type=radio name=\"cmd\" value=\"part\">PART");
+	send_msg(socket,
+		"<br><input type=radio name=\"cmd\" value=\"list\">LIST");
 	send_msg(socket,
 		"<br><input type=radio name=\"cmd\" value=\"topic\">TOPIC");
 	send_msg(socket,
