@@ -1,4 +1,4 @@
-/* $Id: keitai.c,v 1.5 2004/12/05 07:31:31 ichiro Exp $ */
+/* $Id: keitai.c,v 1.7 2005/12/09 15:45:18 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -112,6 +112,15 @@ keitai_start(struct tparam *th)
 		printf("MODE:%s\n", th->l_buff);
 	}
 
+	/* NAMES */
+	if ((s = strstr(th->l_buff, "353"))) {
+		if ((sscanf(th->l_buff, ":%*s 353 %s %*s %s :%[^\n]",
+			a2, a3, a4)) == 3) {
+			if (strcmp(th->real_nickname, a2) == 0)
+				names_recv(th, a3, a4);
+		}
+	}
+
 	return (0);
 }
 
@@ -211,6 +220,27 @@ int priv_recv(struct tparam *th)
 	return (0);
 }
 
+int names_recv(struct tparam *th, char *channel, char *names)
+{
+	int n = 0;
+	char buf[IRC_MAX];
+	char channel2[C_NAME];
+
+	/* channel;  #hoge:*.jp -> %hoge */
+	channel_encode(channel2, channel);
+
+#ifdef DEBUG
+	printf("NAMES:channel=%s, names=%s\n", channel2, names);
+#endif
+
+	for (n = 0; n <= th->ch_count; n++) {
+		if (strstr(th->name[n], channel2))
+                        sprintf(th->member_names[n], " %s", names);
+        }
+
+	return (0);
+}
+
 int topic_recv(struct tparam *th, char *user, char *channel, char *topic)
 {
 	int n = 0;
@@ -224,8 +254,8 @@ int topic_recv(struct tparam *th, char *user, char *channel, char *topic)
 	channel_encode(channel2, channel);
 
 #ifdef DEBUG
-	printf("TOPIC:user=%s, channel=%s, topic=%s, len=%d\n",
-		user, channel2, topic, len);
+	printf("TOPIC:user=%s, channel=%s, topic=%s\n",
+		user, channel2, topic);
 #endif
 	/* '<','>' ---> '&lt;','&gt;' */
 	ltgt_encode(buf, topic);
