@@ -1,4 +1,6 @@
-/* $Id: kircd.h,v 1.2 2004/12/04 12:52:50 ichiro Exp $ */
+/* $Id: kircd.h,v 1.5 2005/12/09 16:06:02 ichiro Exp $ */
+/* #define DEBUG */
+#define DEBUG
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -43,8 +45,8 @@
 #define SERVER 1
 
 #define SBUFLEN 4096
-#define LBUFLEN 1024
-#define HTTPBUF 1024
+#define LBUFLEN 4096
+#define HTTPBUF 4096
 
 #define CONFSEP ";\n"
 
@@ -73,18 +75,23 @@ struct tparam {
 	int s_lock;
 	int max_line;
 	int line_reverse;
+	int cookie_expire;
 	char name[CH_MAX][C_NAME];
 	int  ch_count;
 	char data[CH_MAX][C_HISTORY_NUM][IRC_MAX];
 	int  history_count[CH_MAX];
 	int  read_count[CH_MAX];
 	char topic[CH_MAX][IRC_MAX];
+	char member_names[CH_MAX][IRC_MAX];
 	int  t_empty;	/* trans buffer empty */
 	char postdata[CH_MAX][IRC_MAX];
 
 	/* auth (copy) */
 	char auth_user[40];
 	char auth_pass[40];
+
+	/* http */
+	int h_lock;
 };
 struct config {
 	char hostname[128];
@@ -99,6 +106,7 @@ struct config {
 	char auth_pass[40];
 	int max_line;
 	int line_reverse;
+	int cookie_expire;
 };
 
 int main(int ac, char *av[]);
@@ -115,6 +123,7 @@ extern int priv_recv(struct tparam *);
 extern int topic_recv(struct tparam *, char *, char *, char *);
 extern int part_recv(struct tparam *, char *);
 extern int join_recv(struct tparam *, char *);
+extern int names_recv(struct tparam *, char *, char *);
 
 extern int url_decode_jis(char *, char *);
 extern int url_decode_rawdata(char *, char *);
