@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.2 2004/12/04 12:52:50 ichiro Exp $ */
+/* $Id: main.c,v 1.4 2005/12/09 16:06:02 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -151,6 +151,7 @@ int main(int argc, char *argv[])
 	/* copy config option */
 	th.max_line = cf->max_line;
 	th.line_reverse = cf->line_reverse;
+	th.cookie_expire = cf->cookie_expire;
 	strcpy(th.real_nickname, cf->nickname);
 
 	/* copy auth info */
@@ -296,7 +297,7 @@ lineget(gpointer param)
 		/* bit empty flag */
 		if (th->s_count >= th->s_read)
 			th->s_empty = 1; 
-#ifdef DEBUG
+#ifdef DEBUG2
 		printf("(s_count %d/s_read %d/lcount %d)\n%s\n---------\n",
 			th->s_count, th->s_read, lcount, th->l_buff);
 		printf("s_empty=%d, s_lock=%d\n", th->s_empty, th->s_lock);
